aboutsummaryrefslogtreecommitdiff
path: root/sys/dev/vr
diff options
context:
space:
mode:
authorMike Silbersack <silby@FreeBSD.org>2002-08-05 13:24:06 +0000
committerMike Silbersack <silby@FreeBSD.org>2002-08-05 13:24:06 +0000
commitaff8da70742fa2e324b0632ee6fe3795331ce9bd (patch)
tree1cacb1edbfc93042ff8e1238801891c3d3c62bab /sys/dev/vr
parent42a389ac3e15069bd4f979bb052d246128a2e073 (diff)
Notes
Diffstat (limited to 'sys/dev/vr')
-rw-r--r--sys/dev/vr/if_vr.c7
1 files changed, 6 insertions, 1 deletions
diff --git a/sys/dev/vr/if_vr.c b/sys/dev/vr/if_vr.c
index 74a8d660f7bf..76326b7fa0d4 100644
--- a/sys/dev/vr/if_vr.c
+++ b/sys/dev/vr/if_vr.c
@@ -1406,8 +1406,13 @@ static void vr_init(xsc)
*/
for (i = 0; i < ETHER_ADDR_LEN; i++)
CSR_WRITE_1(sc, VR_PAR0 + i, sc->arpcom.ac_enaddr[i]);
+
+ /* Set DMA size */
+ VR_CLRBIT(sc, VR_BCR0, VR_BCR0_DMA_LENGTH);
+ VR_SETBIT(sc, VR_BCR0, VR_BCR0_DMA_STORENFWD);
- /* BCR0 and BCR1 can override the RXCFG and TXCFG registers,
+ /*
+ * BCR0 and BCR1 can override the RXCFG and TXCFG registers,
* so we must set both.
*/
VR_CLRBIT(sc, VR_BCR0, VR_BCR0_RX_THRESH);